@@ -165,13 +165,13 @@ def get_docstring_arg_type(t: str, is_list: bool = False, is_pyrogram_type: bool
         else:
             return f"``{t.lower()}``"
     elif t == "TLObject" or t == "X":
-        return "Any object from :obj:`~pyrogram.raw.types`"
+        return "Any object from :obj:`~pyroxd.raw.types`"
     elif t == "!X":
-        return "Any method from :obj:`~pyrogram.raw.functions`"
+        return "Any method from :obj:`~pyroxd.raw.functions`"
     elif t.lower().startswith("vector"):
         return "List of " + get_docstring_arg_type(t.split("<", 1)[1][:-1], True)
     else:
-        return f":obj:`{t} <pyrogram.raw.base.{t}>`"
+        return f":obj:`{t} <pyroxd.raw.base.{t}>`"
 
 
 def get_references(t: str, kind: str):
@@ -184,7 +184,7 @@ def get_references(t: str, kind: str):
 
     if t:
         return "\n            ".join(
-            f"- :obj:`{i} <pyrogram.raw.functions.{i}>`"
+            f"- :obj:`{i} <pyroxd.raw.functions.{i}>`"
             for i in t
         ), len(t)
 
@@ -315,7 +315,7 @@ def start(format: bool = False):
 
         constructors = sorted(types_to_constructors[qualtype])
         constr_count = len(constructors)
-        items = "\n            ".join([f"- :obj:`{c} <pyrogram.raw.types.{c}>`" for c in constructors])
+        items = "\n            ".join([f"- :obj:`{c} <pyroxd.raw.types.{c}>`" for c in constructors])
 
         docstring = f"This base type has {constr_count} constructor{'s' if constr_count > 1 else ''} available.\n\n"
         docstring += f"    Constructors:\n        .. hlist::\n            :columns: 2\n\n            {items}"
@@ -374,7 +374,7 @@ def start(format: bool = False):
             )
 
         if c.section == "types":
-            docstring += f"This object is a constructor of the base type :obj:`~pyrogram.raw.base.{c.qualtype}`.\n\n"
+            docstring += f"This object is a constructor of the base type :obj:`~pyroxd.raw.base.{c.qualtype}`.\n\n"
         else:
             docstring += f"Telegram API method.\n\n"
 
