@@ -353,7 +353,7 @@ def pyrogram_api():
                     title = "{}()".format(method)
 
                     f2.write(title + "\n" + "=" * len(title) + "\n\n")
-                    f2.write(".. automethod:: pyrogram.Client.{}()".format(method))
+                    f2.write(".. automethod:: pyroxd.Client.{}()".format(method))
 
             functions = ["idle", "compose"]
 
@@ -362,7 +362,7 @@ def pyrogram_api():
                     title = "{}()".format(func)
 
                     f2.write(title + "\n" + "=" * len(title) + "\n\n")
-                    f2.write(".. autofunction:: pyrogram.{}()".format(func))
+                    f2.write(".. autofunction:: pyroxd.{}()".format(func))
 
         f.write(template.format(**fmt_keys))
 
@@ -517,7 +517,7 @@ def pyrogram_api():
                     title = "{}".format(type)
 
                     f2.write(title + "\n" + "=" * len(title) + "\n\n")
-                    f2.write(".. autoclass:: pyrogram.types.{}()\n".format(type))
+                    f2.write(".. autoclass:: pyroxd.types.{}()\n".format(type))
 
         f.write(template.format(**fmt_keys))
 
@@ -631,7 +631,7 @@ def pyrogram_api():
                     title = "{}()".format(bm)
 
                     f2.write(title + "\n" + "=" * len(title) + "\n\n")
-                    f2.write(".. automethod:: pyrogram.types.{}()".format(bm))
+                    f2.write(".. automethod:: pyroxd.types.{}()".format(bm))
 
         f.write(template.format(**fmt_keys))
 
