@@ -21,7 +21,7 @@ from .auto_name import AutoName
 
 
 class ChatMembersFilter(AutoName):
-    """Chat members filter enumeration used in :meth:`~pyrogram.Client.get_chat_members`"""
+    """Chat members filter enumeration used in :meth:`~pyroxd.Client.get_chat_members`"""
 
     SEARCH = raw.types.ChannelParticipantsSearch
     "Search for members"
