@@ -55,7 +55,7 @@ class SendMediaGroup:
                 For your personal cloud (Saved Messages) you can simply use "me" or "self".
                 For a contact that exists in your Telegram address book you can use his phone number (str).
 
-            media (List of :obj:`~pyrogram.types.InputMediaPhoto`, :obj:`~pyrogram.types.InputMediaVideo`, :obj:`~pyrogram.types.InputMediaAudio` and :obj:`~pyrogram.types.InputMediaDocument`):
+            media (List of :obj:`~pyroxd.types.InputMediaPhoto`, :obj:`~pyroxd.types.InputMediaVideo`, :obj:`~pyroxd.types.InputMediaAudio` and :obj:`~pyroxd.types.InputMediaDocument`):
                 A list describing photos and videos to be sent, must include 2–10 items.
 
             disable_notification (``bool``, *optional*):
@@ -72,7 +72,7 @@ class SendMediaGroup:
                 Protects the contents of the sent message from forwarding and saving.
 
         Returns:
-            List of :obj:`~pyrogram.types.Message`: On success, a list of the sent messages is returned.
+            List of :obj:`~pyroxd.types.Message`: On success, a list of the sent messages is returned.
 
         Example:
             .. code-block:: python
