@@ -28,7 +28,7 @@ class GetMe:
         """Get your own user identity.
 
         Returns:
-            :obj:`~pyrogram.types.User`: Information about the own logged in user/bot.
+            :obj:`~pyroxd.types.User`: Information about the own logged in user/bot.
 
         Example:
             .. code-block:: python
