@@ -20,9 +20,9 @@ import pyroxd
 
 from ..object import Object
 
-"""- :obj:`~pyrogram.types.InputLocationMessageContent`
-    - :obj:`~pyrogram.types.InputVenueMessageContent`
-    - :obj:`~pyrogram.types.InputContactMessageContent`"""
+"""- :obj:`~pyroxd.types.InputLocationMessageContent`
+    - :obj:`~pyroxd.types.InputVenueMessageContent`
+    - :obj:`~pyroxd.types.InputContactMessageContent`"""
 
 
 class InputMessageContent(Object):
@@ -30,7 +30,7 @@ class InputMessageContent(Object):
 
     Pyrogram currently supports the following types:
 
-    - :obj:`~pyrogram.types.InputTextMessageContent`
+    - :obj:`~pyroxd.types.InputTextMessageContent`
     """
 
     def __init__(self):
