@@ -24,4 +24,4 @@ class Update:
         raise pyrogram.StopPropagation
 
     def continue_propagation(self):
-        raise pyrogram.ContinuePropagation
+        raise pyroxd.ContinuePropagation
